[![tests](https://github.com/martvanrijthoven/creationism/actions/workflows/tests.yml/badge.svg)](https://github.com/martvanrijthoven/creationism/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/martvanrijthoven/creationism/branch/main/graph/badge.svg?token=2GG651W294)](https://codecov.io/gh/martvanrijthoven/creationism)
[![docs](https://github.com/martvanrijthoven/creationism/actions/workflows/docs.yml/badge.svg)](https://github.com/martvanrijthoven/creationism/actions/workflows/docs.yml)
# Creationism
    
    Registration
    Configuration
    Creation



